@@ -13,8 +13,8 @@ called.
 
 The following functions are disabled:
 
-    apply, cmp, coerce, execfile, file, raw_input,
-    long, unicode, xrange
+    apply, cmp, coerce, execfile, file, long,
+    raw_input, reduce, reload, unicode, xrange
 
 and this exception class:
 
@@ -33,25 +33,25 @@ from __future__ import division, absolute_import, print_function
 
 import inspect
 
-from . import six
+import six
 
-OBSOLETE_BUILTINS = ['apply', 'cmp', 'coerce', 'execfile', 'file',
-                     'raw_input', 'long', 'unicode', 'xrange',
+OBSOLETE_BUILTINS = ['apply', 'cmp', 'coerce', 'execfile', 'file', 'long',
+                     'raw_input', 'reduce', 'reload', 'unicode', 'xrange',
                      'StandardError']
 
+
 def disabled_function(name):
     '''
     Returns a function that cannot be called
     '''
     def disabled(*args, **kwargs):
-        raise NotImplementedError('obsolete Python 2 builtin {} is disabled'.format(name))
+        raise NameError('obsolete Python 2 builtin {} is disabled'.format(name))
     return disabled
 
+
 if not six.PY3:
     caller = inspect.currentframe().f_back
     
     for fname in OBSOLETE_BUILTINS:
-        def disabled(*args, **kwargs):
-            raise NotImplementedError('obsolete Python 2 builtin {} is disabled'.format(fname))
         caller.f_globals.__setitem__(fname, disabled_function(fname))
 
